@@ -15,7 +15,7 @@
 #                  and http://forum.photome.de/viewtopic.php?f=2&t=353&p=742#p740
 #               7) Kai Lappalainen private communication
 #               8) http://u88.n24.queensu.ca/exiftool/forum/index.php/topic,5223.0.html
-#               9) Iliah Borg private communication (LibRaw)
+#               IB) Iliah Borg private communication (LibRaw)
 #               JD) Jens Duttke private communication
 #------------------------------------------------------------------------------
 
@@ -26,7 +26,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.51';
+$VERSION = '1.53';
 
 sub ProcessFujiDir($$$);
 sub ProcessFaceRec($$$);
@@ -50,6 +50,7 @@ my %testedRAF = (
     '0266' => 'S9500 Ver1.01',
     '0269' => 'S9500 Ver1.02',
     '0271' => 'S3Pro Ver2.71', # UV/IR model?
+    '0300' => 'X-E2',
     '0712' => 'S5000 Ver3.00',
     '0716' => 'S5000 Ver3.00', # (yes, 2 RAF versions with the same Software version)
 );
@@ -691,60 +692,71 @@ my %faceCategories = (
         Count => 36,
         PrintConv => '$val =~ tr/012 /RGB/d; join " ", $val =~ /....../g',
     },
-    0x2000 => { #9
+    0x2000 => { #IB
         Name => 'WB_GRGBLevelsAuto',
         Format => 'int16u',
         Count => 4, # (ignore the duplicate values)
     },
-    0x2100 => { #9
+    0x2100 => { #IB
         Name => 'WB_GRGBLevelsDaylight',
         Format => 'int16u',
         Count => 4,
     },
-    0x2200 => { #9
+    0x2200 => { #IB
         Name => 'WB_GRGBLevelsCloudy',
         Format => 'int16u',
         Count => 4,
     },
-    0x2300 => { #9
+    0x2300 => { #IB
         Name => 'WB_GRGBLevelsDaylightFluor',
         Format => 'int16u',
         Count => 4,
     },
-    0x2301 => { #9
+    0x2301 => { #IB
         Name => 'WB_GRGBLevelsDayWhiteFluor',
         Format => 'int16u',
         Count => 4,
     },
-    0x2302 => { #9
+    0x2302 => { #IB
         Name => 'WB_GRGBLevelsWhiteFluorescent',
         Format => 'int16u',
         Count => 4,
     },
-    0x2310 => { #9
+    0x2310 => { #IB
         Name => 'WB_GRGBLevelsWarmWhiteFluor',
         Format => 'int16u',
         Count => 4,
     },
-    0x2311 => { #9
+    0x2311 => { #IB
         Name => 'WB_GRGBLevelsLivingRoomWarmWhiteFluor',
         Format => 'int16u',
         Count => 4,
     },
-    0x2400 => { #9
+    0x2400 => { #IB
         Name => 'WB_GRGBLevelsTungsten',
         Format => 'int16u',
         Count => 4,
     },
-    # 0x2f00 => WB_GRGBLevelsCustom: int32u count, then count * (int16u GRGBGRGB), ref 9
+    # 0x2f00 => WB_GRGBLevelsCustom: int32u count, then count * (int16u GRGBGRGB), ref IB
     0x2ff0 => {
         Name => 'WB_GRGBLevels',
         Format => 'int16u',
         Count => 4,
     },
+    0x9200 => { #Frank Markesteijn
+        Name => 'RelativeExposure',
+        Format => 'rational32s',
+        ValueConv => 'log($val) / log(2)',
+        ValueConvInv => 'exp($val * log(2))',
+        PrintConv => '$val ? sprintf("%+.1f",$val) : 0',
+        PrintConvInv => '$val',
+    },
+    # 0x9200 - relative exposure? (ref Frank Markesteijn)
     0x9650 => { #Frank Markesteijn
         Name => 'RawExposureBias',
         Format => 'rational32s',
+        PrintConv => '$val ? sprintf("%+.1f",$val) : 0',
+        PrintConvInv => '$val',
     },
     0xc000 => {
         Name => 'RAFData',
@@ -758,11 +770,14 @@ my %faceCategories = (
 %Image::ExifTool::FujiFilm::RAFData = (
     PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
     GROUPS => { 0 => 'MakerNotes', 2 => 'Camera' },
+    DATAMEMBER => [ 0, 4, 8 ],
     FIRST_ENTRY => 0,
     # (FujiFilm image dimensions are REALLY confusing)
+    # --> this needs some cleaning up
     0 => {
         Name => 'RawImageWidth',
         Format => 'int32u',
+        DataMember => 'FujiWidth',
         RawConv => '$val < 10000 ? $$self{FujiWidth} = $val : undef', #5
         ValueConv => '$$self{FujiLayout} ? ($val / 2) : $val',
     },
@@ -771,17 +786,39 @@ my %faceCategories = (
             Name => 'RawImageWidth',
             Condition => 'not $$self{FujiWidth}',
             Format => 'int32u',
+            DataMember => 'FujiWidth',
+            RawConv => '$val < 10000 ? $$self{FujiWidth} = $val : undef', #PH
             ValueConv => '$$self{FujiLayout} ? ($val / 2) : $val',
         },
         {
             Name => 'RawImageHeight',
             Format => 'int32u',
+            DataMember => 'FujiHeight',
+            RawConv => '$$self{FujiHeight} = $val',
             ValueConv => '$$self{FujiLayout} ? ($val * 2) : $val',
         },
     ],
-    8 => {
+    8 => [
+        {
+            Name => 'RawImageWidth',
+            Condition => 'not $$self{FujiWidth}',
+            Format => 'int32u',
+            DataMember => 'FujiWidth',
+            RawConv => '$val < 10000 ? $$self{FujiWidth} = $val : undef', #PH
+            ValueConv => '$$self{FujiLayout} ? ($val / 2) : $val',
+        },
+        {
+            Name => 'RawImageHeight',
+            Condition => 'not $$self{FujiHeight}',
+            Format => 'int32u',
+            DataMember => 'FujiHeight',
+            RawConv => '$$self{FujiHeight} = $val',
+            ValueConv => '$$self{FujiLayout} ? ($val * 2) : $val',
+        },
+    ],
+    12 => {
         Name => 'RawImageHeight',
-        Condition => 'not $$self{FujiWidth}',
+        Condition => 'not $$self{FujiHeight}',
         Format => 'int32u',
         ValueConv => '$$self{FujiLayout} ? ($val * 2) : $val',
     },
@@ -818,10 +855,10 @@ my %faceCategories = (
         OffsetPair => 0xf007,  # point to associated offsets
     },
     # 0xf009 - values: 0, 3
-    0xf00a => 'BlackLevel', #9
+    0xf00a => 'BlackLevel', #IB
     # 0xf00b ?
-    0xf00c => 'WB_GRBLevelsStandard', #9 (GRBXGRBX; X=17 is standard illuminant A, X=21 is D65)
-    0xf00d => 'WB_GRBLevelsAuto', #9
+    0xf00c => 'WB_GRBLevelsStandard', #IB (GRBXGRBX; X=17 is standard illuminant A, X=21 is D65)
+    0xf00d => 'WB_GRBLevelsAuto', #IB
     0xf00e => 'WB_GRBLevels',
     # 0xf00f ?
 );
@@ -1163,7 +1200,7 @@ FujiFilm maker notes in EXIF information, and to read/write FujiFilm RAW
 
 =head1 AUTHOR
 
-Copyright 2003-2015, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
